@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1301, USA.
 *)
 
 module Make_with_wrapped_functions
@@ -274,6 +274,15 @@ struct
 
   let a_name = string_attrib "name"
 
+  let a_allowfullscreen =
+    constant_attrib "allowfullscreen"
+
+  let a_allowpaymentrequest =
+    constant_attrib "allowpaymentrequest"
+
+  let a_referrerpolicy x =
+    user_attrib C.string_of_referrerpolicy "referrerpolicy" x
+
   let a_autocomplete x =
     user_attrib C.onoff_of_bool "autocomplete" x
 
@@ -292,6 +301,8 @@ struct
   let a_crossorigin x =
     user_attrib C.string_of_big_variant "crossorigin" x
 
+  let a_integrity = string_attrib "integrity"
+
   let a_mediagroup = string_attrib "mediagroup"
 
   let a_challenge = string_attrib "challenge"
@@ -659,6 +670,8 @@ struct
 
   let noscript = star "noscript"
 
+  let template = star "template"
+
   let article = star "article"
 
   let aside = star "aside"
@@ -897,6 +910,17 @@ struct
     | `Tv -> "tv"
     | `Raw_mediadesc s -> s
 
+  let string_of_referrerpolicy = function
+    | `Empty -> ""
+    | `No_referrer -> "no-referrer"
+    | `No_referrer_when_downgrade -> "no-referrer-when-downgrade"
+    | `Origin -> "origin"
+    | `Origin_when_cross_origin -> "origin-when-cross-origin"
+    | `Same_origin -> "same-origin"
+    | `Strict_origin -> "strict-origin"
+    | `Strict_origin_when_cross_origin -> "strict-origin-when-cross-origin"
+    | `Unsafe_url -> "unsafe-url"
+
   let string_of_big_variant = function
     | `Anonymous -> "anonymous"
     | `Async -> "async"
