@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1301, USA.
 *)
 
 (** HTML signatures for the functorial interface. *)
@@ -256,6 +256,10 @@ module type T = sig
 
   (** {3 Other attributes} *)
 
+  val a_allowfullscreen : unit -> [> | `Allowfullscreen] attrib
+
+  val a_allowpaymentrequest : unit -> [> | `Allowpaymentrequest] attrib
+
   val a_autocomplete : (bool[@onoff]) wrap -> [> | `Autocomplete] attrib
 
   val a_async : unit -> [> | `Async] attrib
@@ -269,6 +273,9 @@ module type T = sig
   val a_crossorigin :
     [< | `Anonymous | `Use_credentials ] wrap -> [> | `Crossorigin ] attrib
 
+  val a_integrity :
+    string wrap -> [> | `Integrity ] attrib
+
   val a_mediagroup : string wrap -> [> | `Mediagroup ] attrib
 
   val a_challenge : text wrap -> [> | `Challenge] attrib
@@ -343,6 +350,10 @@ module type T = sig
 
   val a_radiogroup : text wrap -> [> | `Radiogroup] attrib
 
+  val a_referrerpolicy : referrerpolicy wrap -> [> `Referrerpolicy] attrib
+  (** @see <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/iframe#Attributes>
+  *)
+
   val a_required : unit -> [> | `Required] attrib
 
   val a_reversed : unit -> [> | `Reversed] attrib
@@ -433,7 +444,7 @@ module type T = sig
       should ignore leading zeros. *)
 
   val a_mime_type : contenttype wrap -> [> | `Mime_type] attrib
-  [@@reflect.attribute "type" ["object"; "embed"; "area"; "link"]]
+  [@@reflect.attribute "type" ["object"; "embed"; "area"; "link"; "source"]]
   (** This attribute gives an advisory hint as to the content type
       of the content available at the link target address. It
       allows user agents to opt to use a fallback mechanism rather
@@ -653,7 +664,7 @@ module type T = sig
 
   val a_property : string wrap -> [> | `Property] attrib
 
-  (** {3 {{: https://www.w3.org/TR/wai-aria-1.1/} WAI-ARIA} support} *)
+  (** {3 ARIA support} *)
 
   (** {{: https://www.w3.org/TR/wai-aria-1.1/} WAI-ARIA} is a specification
       written by the W3C, defining a set of additional HTML attributes that can
@@ -684,11 +695,13 @@ module type T = sig
   val html :
     ?a: ((html_attrib attrib) list) ->
     [< | head] elt wrap -> [< | body] elt wrap -> [> | html] elt
+  [@@reflect.filter_whitespace]
   [@@reflect.element "html"]
 
   val head :
     ?a: ((head_attrib attrib) list) ->
     [< | title] elt wrap -> (head_content_fun elt) list_wrap -> [> | head] elt
+  [@@reflect.filter_whitespace]
   [@@reflect.element "head"]
 
   val base : ([< | base_attrib], [> | base]) nullary
@@ -755,10 +768,10 @@ module type T = sig
   val dl : ([< | dl_attrib], [< | dl_content_fun], [> | dl]) star
 
   val ol : ([< | ol_attrib], [< | ol_content_fun], [> | ol]) star
-  [@@reflect.element "ol"]
+  [@@reflect.filter_whitespace]
 
   val ul : ([< | ul_attrib], [< | ul_content_fun], [> | ul]) star
-  [@@reflect.element "ul"]
+  [@@reflect.filter_whitespace]
 
   val dd : ([< | dd_attrib], [< | dd_content_fun], [> | dd]) star
 
@@ -897,6 +910,7 @@ module type T = sig
     ?thead: [< | thead] elt wrap ->
     ?tfoot: [< | tfoot] elt wrap ->
     ([< | table_attrib], [< | table_content_fun], [> | table]) star
+  [@@reflect.filter_whitespace]
   [@@reflect.element "table"]
 
   val tablex :
@@ -905,27 +919,33 @@ module type T = sig
     ?thead: [< | thead] elt wrap ->
     ?tfoot: [< | tfoot] elt wrap ->
     ([< | tablex_attrib], [< | tablex_content_fun], [> | tablex]) star
+  [@@reflect.filter_whitespace]
   [@@reflect.element "table" "table"]
 
   val colgroup :
     ([< | colgroup_attrib], [< | colgroup_content_fun], [> | colgroup]) star
+  [@@reflect.filter_whitespace]
 
   val col : ([< | col_attrib], [> | col]) nullary
 
   val thead :
     ([< | thead_attrib], [< | thead_content_fun], [> | thead]) star
+  [@@reflect.filter_whitespace]
 
   val tbody :
     ([< | tbody_attrib], [< | tbody_content_fun], [> | tbody]) star
+  [@@reflect.filter_whitespace]
 
   val tfoot :
     ([< | tfoot_attrib], [< | tfoot_content_fun], [> | tfoot]) star
+  [@@reflect.filter_whitespace]
 
   val td : ([< | td_attrib], [< | td_content_fun], [> | td]) star
 
   val th : ([< | th_attrib], [< | th_content_fun], [> | th]) star
 
   val tr : ([< | tr_attrib], [< | tr_content_fun], [> | tr]) star
+  [@@reflect.filter_whitespace]
 
   (** {3 Forms} *)
 
@@ -953,7 +973,7 @@ module type T = sig
 
   val select :
     ([< | select_attrib], [< | select_content_fun], [> | select]) star
-  [@@reflect.element "select"]
+  [@@reflect.filter_whitespace]
 
   val datalist :
     ?children:(
@@ -962,6 +982,7 @@ module type T = sig
         | `Phras of ([< | phrasing] elt) list_wrap
       ]) ->
     ([< | datalist_attrib], [> | datalist]) nullary
+  [@@reflect.filter_whitespace]
   [@@reflect.element "datalist"]
 
   val optgroup :
@@ -1029,10 +1050,16 @@ module type T = sig
 
   val script :
     ([< | script_attrib], [< | script_content_fun], [> | script]) unary
+  [@@reflect.element "script"]
 
   val noscript :
     ([< | noscript_attrib], [< | noscript_content_fun], [> | noscript]) star
 
+  val template :
+    ([< | template_attrib], [< | template_content_fun], [> | template]) star
+  (** @see <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/template>
+      Template element documentation on MDN *)
+
   val meta : ([< | meta_attrib], [> | meta]) nullary
 
   (** {3 Style Sheets} *)
@@ -1059,7 +1086,7 @@ module type T = sig
   [@@ocaml.deprecated "Use txt instead"]
   (** @deprecated Use txt instead *)
 
-  (** {2 Conversion with untyped representation} 
+  (** {2 Conversion with untyped representation}
 
       WARNING: These functions do not ensure HTML or SVG validity! You should
       always explicitly given an appropriate type to the output.
@@ -1148,7 +1175,7 @@ module Make
     (Svg : Svg_sigs.T with module Xml := Xml) :
 sig
 
-  (** See {!modtype:Html_sigs.T}. *)
+  (** See {!module-type:Html_sigs.T}. *)
   module type T = T
     with type 'a Xml.W.t = 'a Xml.W.t
      and type 'a Xml.W.tlist = 'a Xml.W.tlist
@@ -1189,6 +1216,9 @@ module type Wrapped_functions = sig
   val string_of_mediadesc :
     ([< Html_types.mediadesc_token] list, string) Xml.W.ft
 
+  val string_of_referrerpolicy :
+    ([< Html_types.referrerpolicy], string) Xml.W.ft
+
   val string_of_numbers : (Html_types.numbers, string) Xml.W.ft
 
   val string_of_sandbox :
