@@ -16,12 +16,12 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1301, USA.
 *)
 
 (* _fun prefix are the types that must be used
    in Html_sigs. They are more restrictive as
-   some param are already taken as seperate argument,
+   some param are already taken as separate argument,
    to ensure better compatibility.
    SC *)
 
@@ -398,6 +398,8 @@ type listed = [ | resetable | submitable | `Fieldset ]
 
 type formassociated = [ | listed | `Progress | `Meter | `Label ]
 
+type subressource_integrity = [ | `Crossorigin | `Integrity ]
+(** @see <https://developer.mozilla.org/en-US/docs/Web/Security/Subresource_Integrity> *)
 
 (** Transparent elements.
     Such elements have a part of they children in their data
@@ -467,6 +469,7 @@ type (+'interactive, +'noscript, +'regular) transparent_without_media =
 (** Metadata without title *)
 type metadata_without_title =
   [
+    | `Template
     | `Style
     | `Script
     | `Noscript of [ | `Meta | `Link | `Style ]
@@ -513,6 +516,7 @@ type core_phrasing =
     | `U
     | `Svg
     | `Time
+    | `Template
     | `Sup
     | `Sub
     | `Strong
@@ -550,6 +554,7 @@ type core_phrasing_without_noscript =
     | `Var
     | `U
     | `Time
+    | `Template
     | `Sup
     | `Sub
     | `Svg
@@ -587,6 +592,7 @@ type core_phrasing_without_interactive =
     | `U
     | `Img
     | `Time
+    | `Template
     | `Sup
     | `Sub
     | `Strong
@@ -622,6 +628,7 @@ type core_phrasing_without_media =
     | `Var
     | `U
     | `Time
+    | `Template
     | `Svg
     | `Sup
     | `Sub
@@ -688,7 +695,7 @@ type (+'a, +'b) between_phrasing_and_phrasing_without_interactive =
         > `Abbr `B `Bdo `Br `Canvas `Cite `Code `Command
         `Datalist `Del `Dfn `Em `I `Img `Ins `Kbd `Map `Mark `Meter
         `Noscript `Object `PCDATA `Progress `Q `Ruby `Samp `Script
-        `Small `Span `Strong `Sub `Sup `Svg `Time `U `Var  `Wbr  ] as 'a)
+        `Small `Span `Strong `Sub `Sup `Svg `Template `Time `U `Var `Wbr ] as 'a)
 
 (** Phrasing without the interactive markups *)
 type phrasing_without_dfn =
@@ -699,6 +706,7 @@ type phrasing_without_dfn =
     | `Var
     | `U
     | `Time
+    | `Template
     | `Sup
     | `Sub
     | `Strong
@@ -735,6 +743,7 @@ type phrasing_without_label =
     | `Var
     | `U
     | `Time
+    | `Template
     | `Sup
     | `Sub
     | `Strong
@@ -771,6 +780,7 @@ type phrasing_without_progress =
     | `Var
     | `U
     | `Time
+    | `Template
     | `Sup
     | `Sub
     | `Strong
@@ -809,6 +819,7 @@ type phrasing_without_time =
     | `Wbr
     | `Var
     | `U
+    | `Template
     | `Sup
     | `Sub
     | `Strong
@@ -848,6 +859,7 @@ type phrasing_without_meter =
     | `Var
     | `U
     | `Time
+    | `Template
     | `Sup
     | `Img | `Img_interactive
     | `Sub
@@ -1051,7 +1063,7 @@ type +'a between_flow5_and_flow5_without_interactive_header_footer =
        `Input `Ins `Kbd `Keygen `Label `Map`Mark `Menu `Meter `Nav `Noscript
        `Object `Ol `Output `P `PCDATA `Pre `Progress `Q `Ruby `Samp `Script
        `Section `Select `Small `Span `Strong `Style `Sub `Sup `Svg `Table
-       `Textarea `Time `U `Ul `Var `Video `Wbr] as 'a
+       `Template `Textarea `Time `U `Ul `Var `Video `Wbr] as 'a
 
 type (+'a, +'b) between_flow5_and_flow5_without_header_footer =
   [< core_flow5
@@ -1067,7 +1079,7 @@ type (+'a, +'b) between_flow5_and_flow5_without_header_footer =
       `Mark `Menu `Meter `Nav `Noscript `Object `Object_interactive
       `Ol `Output `P `PCDATA `Pre `Progress `Q `Ruby `Samp `Script
       `Section `Select `Small `Span `Strong `Style `Sub `Sup `Svg
-      `Table `Textarea `Time `U `Ul `Var `Video `Video_interactive
+      `Table `Template `Textarea `Time `U `Ul `Var `Video `Video_interactive
       `Wbr ] as 'a
 
 type flow5_without_form =
@@ -1705,6 +1717,8 @@ type iframe_content_fun = [ | `PCDATA ]
 type iframe_attrib =
   [
     | common
+    | `Allowfullscreen
+    | `Allowpaymentrequest
     | `Src
     | (*| `Srcdoc*)
       `Name
@@ -1712,6 +1726,7 @@ type iframe_attrib =
     | `Seamless
     | `Width
     | `Height
+    | `Referrerpolicy
   ]
 
 type object__content = [ | flow5 | `Param ]
@@ -1925,12 +1940,12 @@ type td_content_fun = [ | flow5 ]
 
 type td_attrib = [ | common | `Colspan | `Headers | `Rowspan ]
 
-(* NAME: th, KIND: star, TYPE: [= common | `Colspan | `Headers | `Rowspan | `Scope], [= phrasing], [=`Th], ARG: [= phrasing], ATTRIB:  OUT: [=`Th] *)
+(* NAME: th, KIND: star, TYPE: [= common | `Colspan | `Headers | `Rowspan | `Scope], [= flow5], [=`Th], ARG: [= flow5], ATTRIB:  OUT: [=`Th] *)
 type th = [ | `Th ]
 
-type th_content = [ | phrasing ]
+type th_content = [ | flow5 ]
 
-type th_content_fun = [ | phrasing ]
+type th_content_fun = [ | flow5 ]
 
 type th_attrib = [ | common | `Colspan | `Headers | `Rowspan | `Scope ]
 
@@ -2225,13 +2240,23 @@ type style_attrib = [ | common | `Media | `Mime_type | `Scoped ]
 type script = [ | `Script ]
 
 type script_attrib =
-  [ | common | `Async | `Charset | `Src | `Defer | `Mime_type
+  [ | common | subressource_integrity
+    | `Async | `Charset | `Src | `Defer | `Mime_type
   ]
 
 type script_content = [ | `PCDATA ]
 
 type script_content_fun = [ | `PCDATA ]
 
+(* NAME: template, KIND: star, TYPE: [= common ], [= flow5 ], [=`Template], ARG: [= flow5 ], ATTRIB:  OUT: [=`Template] *)
+type template = [ | `Template ]
+
+type template_attrib = [ | common ]
+
+type template_content = [ | flow5 ]
+
+type template_content_fun = [ | flow5 ]
+
 (* NAME: link, KIND: nullary, TYPE: [= common | `Hreflang | `Media | `Rel | `Href | `Sizes | `Mime_type ], [=`Link], ARG: notag, ATTRIB:  OUT: [=`Link] *)
 type link = [ | `Link ]
 
@@ -2240,9 +2265,22 @@ type link_content = notag
 type link_content_fun = notag
 
 type link_attrib =
-  [ | common | `Hreflang | `Media | `Rel | `Href | `Sizes | `Mime_type
+  [ | common | subressource_integrity
+    | `Hreflang | `Media | `Rel | `Href | `Sizes | `Mime_type
   ]
 
+type referrerpolicy = [
+  | `Empty
+  | `No_referrer
+  | `No_referrer_when_downgrade
+  | `Origin
+  | `Origin_when_cross_origin
+  | `Same_origin
+  | `Strict_origin
+  | `Strict_origin_when_cross_origin
+  | `Unsafe_url
+]
+
 type big_variant =
   [ `W3_org_1999_xhtml
   | `Default
