@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1301, USA.
 *)
 
 (** SVG signatures for the functorial interface. *)
@@ -156,6 +156,8 @@ module type T = sig
 
   val a_id : string wrap -> [> | `Id ] attrib
 
+  val a_user_data : string -> string wrap -> [> | `User_data] attrib
+
   val a_xml_base : iri wrap -> [> | `Xml_Base ] attrib
     [@@ocaml.deprecated "Removed in SVG2"]
   (** @deprecated Removed in SVG2 *)
@@ -1047,7 +1049,7 @@ module type NoWrap = T with module Xml.W = Xml_wrap.NoWrap
 (** Signature functor for {!Svg_f.Make}. *)
 module Make (Xml : Xml_sigs.T) : sig
 
-  (** See {!modtype:Svg_sigs.T}. *)
+  (** See {!module-type:Svg_sigs.T}. *)
   module type T = T
     with type 'a Xml.W.t = 'a Xml.W.t
      and type 'a Xml.W.tlist = 'a Xml.W.tlist
