@@ -1,12 +1,4 @@
-open Tyxml
-
-let to_string = Format.asprintf "%a" (Html.pp_elt ())
-
-let tyxml_tests l =
-  let f (name, (ty : Html_types.body_content Html.elt), s) =
-    name, `Quick, fun () -> Alcotest.(check string) name (to_string ty) s
-  in
-  List.map f l
+open Tyxml_test
 
 let html_elements = "html elements", tyxml_tests Html.[
 
@@ -18,6 +10,10 @@ let html_elements = "html elements", tyxml_tests Html.[
   canvas [a []],
   "<canvas><a></a></canvas>";
 
+  "template",
+  template ~a:[a_id "idtmpl"] [p [txt "Template"]],
+  "<template id=\"idtmpl\"><p>Template</p></template>" ;
+
 ]
 
 let escaping = "html escaping", tyxml_tests Html.[
