@@ -3,55 +3,7 @@
     This file is here to torture the ppx. Tests that are directly related to
     html or svg should go to the other files.
 *)
-
-open Tyxml
-
-module type LANGUAGE = sig
-  include Xml_sigs.Typed_pp
-  type 'a wrap
-  type 'a list_wrap
-  val pp_wrap :
-    (Format.formatter -> 'a -> unit) ->
-    Format.formatter -> 'a wrap -> unit
-  val pp_wrap_list :
-    (Format.formatter -> 'a -> unit) ->
-    Format.formatter -> 'a list_wrap -> unit
-  val totl : Xml.elt list_wrap -> ('a elt) list_wrap
-  val toeltl : ('a elt) list_wrap -> Xml.elt list_wrap
-end
-
-module TyTests (Language : LANGUAGE) = struct
-  module Testable = struct
-    type t = Xml.elt Language.list_wrap
-    let pp fmt x =
-      Language.pp_wrap_list
-        (Language.pp_elt ())
-        fmt (Language.totl x)
-    let equal = (=)
-  end
-
-  let make l =
-    let f (name, ty1, ty2) =
-      name, `Quick, fun () ->
-        Alcotest.(check (module Testable)) name
-          (Language.toeltl ty1) (Language.toeltl ty2)
-    in
-    List.map f l
-end
-
-module Html = struct
-  include Tyxml.Html
-  let pp_wrap pp = pp
-  let pp_wrap_list pp = Format.pp_print_list ~pp_sep:(fun _ () -> ()) pp
-end
-module Svg = struct
-  include Tyxml.Svg
-  let pp_wrap pp = pp
-  let pp_wrap_list pp = Format.pp_print_list ~pp_sep:(fun _ () -> ()) pp
-end
-module HtmlTests = TyTests (Html)
-module SvgTests = TyTests (Svg)
-
+open Tyxml_test
 
 let basics = "ppx basics", HtmlTests.make Html.[
 
@@ -137,10 +89,55 @@ let basics = "ppx basics", HtmlTests.make Html.[
   [[%html "<ol>   <li>foo</li>  <li>bar</li>   </ol>"]],
   [ol [li [txt "foo"] ; li [txt "bar"]]] ;
 
+  "whitespace in tr",
+  [[%html "<tr>   <td>foo</td>    <td>bar</td>   </tr>"]],
+  [tr [td [txt "foo"] ; td [txt "bar"]]] ;
+
+  "whitespace in table",
+  [[%html "<table>    <tr><td>foo</td></tr>   <tr><td>bar</td></tr>   </table>"]],
+  [tablex [tbody [tr [td [txt "foo"]] ; tr [td [txt "bar"]]]]] ;
+
+  "whitespace in table, full example",
+  [[%html "<table>
+  <caption>txt</caption>
+  <colgroup>
+    <col span=\"2\">
+  </colgroup>
+  <thead>
+    <tr>
+      <th>h1</th>
+      <th>h2</th>
+    </tr>
+  </thead>
+  <tbody>
+    <tr>
+      <td>b1</td>
+      <td>b2</td>
+    </tr>
+  </tbody>
+  <tfoot>
+    <tr>
+      <td>f1</td>
+      <td>f2</td>
+    </tr>
+  </tfoot>
+</table>"]],
+  [tablex ~caption:(caption [txt "txt"])
+    ~columns:[colgroup [col ~a:[a_span 2] ()]]
+    ~thead:(thead [tr [th [txt "h1"] ; th [txt "h2"]]])
+    ~tfoot:(tfoot [tr [td [txt "f1"] ; td [txt "f2"]]])
+    [tbody [tr [td [txt "b1"] ; td [txt "b2"]]]]] ;
+
   "whitespace in select",
   [[%html {|<select>  <option value="bar">bar</option>  </select>|}]],
   [select [option ~a:[a_value "bar"] @@ txt "bar"]] ;
 
+  "datalist",
+  [[%html {|<datalist>
+	<option value="foo">foo</option>
+</datalist>|}]],
+  [datalist ~children:(`Options [option ~a:[a_value "foo"] (txt "foo")]) ()];
+  
   "comments",
   [[%html {|<div><p>a</p><!-- b --><hr/></div>|}]],
   [div [p [txt "a"]; tot (Xml.comment " b "); hr ()]] ;
@@ -149,12 +146,32 @@ let basics = "ppx basics", HtmlTests.make Html.[
   [[%html {|<figure> <figcaption> hello </figcaption> <img src="foo.jpg" alt="a" /> </figure>|}]],
   [figure ~figcaption:(`Top (figcaption [txt " hello "]))
      [txt " "; img ~src:"foo.jpg" ~alt:"a" () ; txt " " ]];
-  
+
   "figcaption last",
   [[%html {|<figure> <img src="foo.jpg" alt="a" /> <figcaption> hello </figcaption> </figure>|}]],
   [figure ~figcaption:(`Bottom (figcaption [txt " hello "]))
      [txt " "; img ~src:"foo.jpg" ~alt:"a" () ; txt " " ]];
-  
+
+  "type in source",
+  [[%html {|<source src="foo.mp3" type="audio/mpeg"/>|}]],
+  [source ~a:[a_src "foo.mp3"; a_mime_type "audio/mpeg"] ()];
+    
+  "table with body",
+  [[%html "<table><tbody></tbody></table>"]],
+  [tablex [tbody []]];
+
+  "table with antiquot body",
+  [[%html "<table>"[tbody []]"</table>"]],
+  [tablex [tbody []]];
+
+  "table with tr",
+  [[%html "<table><tr></tr></table>"]],
+  [tablex [tbody [tr[]]]];
+
+  "table with antiquot tr",
+  [[%html "<table><tbody>"[tr []]"</tbody></table>"]],
+  [tablex [tbody [tr[]]]];
+
 ]
 
 let attribs = "ppx attribs", HtmlTests.make Html.[
@@ -214,6 +231,19 @@ let attribs = "ppx attribs", HtmlTests.make Html.[
   "touch events",
   [[%html "<div ontouchstart='alert()'></div>"]],
   [div ~a:[a_ontouchstart "alert()"] []] ;
+
+  "empty string as referrer policy",
+  [[%html "<iframe referrerpolicy=''></iframe>"]],
+  [iframe ~a:[a_referrerpolicy `Empty] []];
+
+  "dashes in referrer policy",
+  [[%html "<iframe referrerpolicy='no-referrer-when-downgrade'></iframe>"]],
+  [iframe ~a:[a_referrerpolicy `No_referrer_when_downgrade] []];
+
+  "html data-*",
+  [[%html "<div data-foo='valfoo'></div>"]],
+  [div
+    ~a:[a_user_data "foo" "valfoo"] []] ;
 ]
 
 let ns_nesting = "namespace nesting" , HtmlTests.make Html.[
@@ -259,6 +289,11 @@ let svg = "svg", SvgTests.make Svg.[
   [text
     ~a:[a_dx_list [1., None; 2., None]; a_dy_list [3., None; 4., None]] []] ;
 
+  "svg data-*",
+  [[%svg "<text data-foo='valfoo' />"]],
+  [text
+    ~a:[a_user_data "foo" "valfoo"] []] ;
+
   "feColorMatrix type",
   [[%svg "<feColorMatrix type='matrix'/>"]],
   [feColorMatrix ~a:[a_feColorMatrix_type `Matrix] []] ;
@@ -326,38 +361,15 @@ let svg_element_names = "svg element names", SvgTests.make Svg.[
 
 ]
 
-(* The regular HTML module, but with most type equality hidden. 
-   This forces the use of the wrapping functions provided in Xml.W.
-*)
-module HtmlWrapped : sig
-  include Html_sigs.T
-    with type Xml.elt = Tyxml.Xml.elt
-     and type 'a elt = 'a Html.elt
-  include LANGUAGE
-    with type 'a elt := 'a elt
-     and type 'a wrap := 'a wrap
-     and type 'a list_wrap := 'a list_wrap
-     and type doc := doc
-end = struct
-  include Html
-  module Svg = Svg
-end
-module HtmlWrappedTests = TyTests(HtmlWrapped)
-
-let (@:) h t =  HtmlWrapped.Xml.W.(cons (return h) t)
-let (@-) =  HtmlWrapped.Xml.W.append
-let nil = HtmlWrapped.Xml.W.nil
-let (!) = HtmlWrapped.Xml.W.return
-let (!:) x = x @: nil ()
 
 let wrapping =
   let module Html = HtmlWrapped in
   "wrapping", HtmlWrappedTests.make Html.[
-    
+
   "elem",
   !:[%html "<p></p>"],
   !:(p (nil ())) ;
-  
+
   "child",
   !:[%html "<p><span></span></p>"],
   !:(p (span (nil ()) @: nil ())) ;
@@ -381,7 +393,7 @@ let wrapping =
   "txt",
   !:[%html "<p>foo</p>"],
   !:(p (txt !"foo" @: nil ())) ;
-  
+
   "wrapped functions",
   !:[%html "<input method=get />"],
   !:(input ~a:[a_method !`Get] ())
@@ -393,10 +405,10 @@ let elt1() = !: HtmlWrapped.(span !: (txt !"one"))
 let elt2() = !: HtmlWrapped.(b !: (txt !"two"))
 let id = !"pata"
 
-let antiquot = 
+let antiquot =
   let module Html = HtmlWrapped in
   "ppx antiquot", HtmlWrappedTests.make Html.[
-  
+
   "child",
   !:[%html "<p>" (elt1()) "</p>"],
   !:(p (elt1()));
